@@ -1,28 +1,41 @@
 use crate::*;
 use actix_files::Files;
 use actix_web::{get, App, HttpResponse, HttpServer};
+use once_cell::sync::Lazy;
 use std::{
     env::set_current_dir,
     fs::{canonicalize, read_to_string},
-    io::Result,
+    io::{Error, ErrorKind, Result},
     path::Path,
+    sync::Mutex,
 };
 use temp_dir::TempDir;
 
-pub(crate) const ROOT: &str = "reveal.yaml";
-const WATERMARK: &[u8] = include_bytes!("assets/img/watermark.png");
-const ICON: &[u8] = include_bytes!("assets/img/icon.png");
+static ROOT: Lazy<Mutex<String>> = Lazy::new(|| Mutex::new("".to_owned()));
+static CACHE: Lazy<Mutex<String>> = Lazy::new(|| Mutex::new("".to_owned()));
+const WATERMARK: &[u8] = include_bytes!("assets/help/watermark.png");
+const ICON: &[u8] = include_bytes!("assets/help/icon.png");
 const HELP_DOC: &str = include_str!("assets/reveal.yaml");
 
+macro_rules! read_yaml {
+    () => {
+        loader(&read_to_string(ROOT.lock().unwrap().as_str())?, "/static/")?
+    };
+}
+
 /// Launch function.
-pub async fn launch<P>(port: u16, path: P) -> Result<()>
+pub async fn serve<P>(port: u16, path: P, project: &str, cache: bool) -> Result<()>
 where
     P: AsRef<Path>,
 {
     set_current_dir(path.as_ref())?;
+    ROOT.lock().unwrap().push_str(project);
+    if cache {
+        CACHE.lock().unwrap().push_str(&read_yaml!());
+    }
     let temp = match TempDir::new() {
         Ok(v) => v,
-        Err(s) => return err!(s),
+        Err(s) => return Err(Error::new(ErrorKind::InvalidData, s)),
     };
     // Expand Reveal.js
     extract(temp.path())?;
@@ -56,13 +69,13 @@ mod site {
 
     #[get("/")]
     pub(super) async fn index() -> Result<HttpResponse> {
-        let yaml = match read_to_string(ROOT) {
-            Ok(s) => s,
-            Err(_) => return err!("can not found reveal.yaml file"),
-        };
         Ok(HttpResponse::Ok()
             .content_type("text/html;charset=utf-8")
-            .body(loader(&yaml, "/static/")?))
+            .body(if CACHE.lock().unwrap().is_empty() {
+                read_yaml!()
+            } else {
+                CACHE.lock().unwrap().clone()
+            }))
     }
 
     #[get("/help/")]
